package hu.tigra.eing.ingatlan.inyer.adatvaltozas.alapadat;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import hu.tigra.eing.common.core.message.Response;
import hu.tigra.eing.common.entities.ingatlan.IngatlanAzonosito;
import hu.tigra.eing.ingatlan.inyer.adatvaltozas.TulajdoniLapType;
import hu.tigra.eing.ingatlan.inyer.data.CimDTO;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.ToString;

import java.util.List;
import java.util.UUID;

@Data
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, property = "type")
@JsonSubTypes({
        @JsonSubTypes.Type(value = FoldreszletDTO.class, name = "FOLDRESZLET"),
        @JsonSubTypes.Type(value = EpitmenyDTO.class, name = "EPITMENY"),
        @JsonSubTypes.Type(value = EOIEpitmenyDTO.class, name = "EOI_EPITMENY"),
        @JsonSubTypes.Type(value = EOIEpitmenyreszDTO.class, name = "EOI_EPITMENYRESZ")
})
@JsonIgnoreProperties(ignoreUnknown = true)
@Schema(
        description = "Általános ingatlan leíró struktúra",
        subTypes = {
                FoldreszletDTO.class,
                EpitmenyDTO.class,
                EOIEpitmenyDTO.class,
                EOIEpitmenyreszDTO.class},
        discriminatorProperty = "type")
@ToString(of = {"ingatlanId", "ingatlanAzonosito", "terkepiAzonosito", "aktiv"})
public abstract class BaseIngatlanDTO implements Response {

    @Schema(description = "az ingatlan azonosítója (ID)")
    private Long ingatlanId;

    @Schema(description = "az ingatlan egységes azonosítója")
    private UUID oenyAzonosito;

    @Schema(description = "az ingatlan üzleti azonosítója (település, fekvés, helyrajzi szám)")
    private IngatlanAzonosito ingatlanAzonosito;

    @Schema(description = "az objektum térképi azonosítója")
    private Long terkepiAzonosito;

    @Schema(description = "az ingatlan címek hivatkozása az MDM Címregiszterben")
    private List<CimDTO> cimek;

    @Schema(description = "KCR azonosító lista")
    private List<String> kcrIdLista;

    @Schema(description = "az ingatlan elsődleges EOVX koordinátája (INYER KADAT által nem tárolt adat)")
    private Long elsodlegesEovkoordinataX;

    @Schema(description = "az ingatlan elsődleges EOVY koordinátája (INYER KADAT által nem tárolt adat)")
    private Long elsodlegesEovkoordinataY;

    @Schema(description = "megjegyzés")
    private String ingatlanMegjegyzes;

    @Schema(description = "Bejegyző határozat")
    private HatarozatDTO ingatlanBejegyzoHatarozat;

    @Schema(description = "Törlő határozat")
    private HatarozatDTO ingatlanTorloHatarozat;

    @Schema(description = "Aktív-e az ingatlan")
    private Boolean aktiv;

    @Schema(description = "Tulajdoni lap típusa")
    private TulajdoniLapType tulajdoniLapType;

    @Schema(description = "Az ingatlan típusa", requiredMode = Schema.RequiredMode.REQUIRED)
    public abstract String getType();

    public void setType(String type) {}
}
