package hu.tigra.eing.ingatlan.inyer.data;

import hu.tigra.eing.common.core.annotation.AdditionalApiModel;
import hu.tigra.eing.common.entities.ingatlan.IngatlanAzonosito;
import hu.tigra.eing.common.entities.mdm.MDMStringReference;
import hu.tigra.eing.ingatlan.inyer.adatvaltozas.alapadat.HatarozatDTO;
import hu.tigra.eing.ingatlan.inyer.adatvaltozas.ingatlankieg.IngatlanKiegeszitoadatok;
import hu.tigra.eing.ingatlan.inyer.adatvaltozas.jogosult.Jogosult;
import hu.tigra.eing.ingatlan.inyer.adatvaltozas.jogtenykieg.JogTenyKiegeszitoadatok;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serializable;
import java.util.List;

@Data
@AdditionalApiModel
@Schema(description = "Ingatlanhoz tartozó jog és tény bejegyzések")
public class BejegyzesDTO implements Comparable<BejegyzesDTO>, Serializable {

    private Long tullapresz;
    private Long bejegyzesSorszam;
    private BejegyzesTipus bejegyzesTipus;

    // egyeb kozos adatok
    private Long terkepiAzonosito;

    // a migrált bejegyzéseknek csak ebben van adata, ezért szükség van rá
    private String bejegyzesSzovegesTartalma;

    private String bejegyzesSzovegesTartalmaSorszam;
    private String bejegyzesSzovegesTartalmaBejegyzesTargya;
    private String bejegyzesSzovegesTartalmaBejegyzoHatarozat;
    private String bejegyzesSzovegesTartalmaTorloHatarozat;
    private String bejegyzesSzovegesTartalmaJogosultAdatai;
    private String bejegyzesSzovegesTartalmaJogosultCime;
    private String bejegyzesSzovegesTartalmaKiegeszitoadatok;
    private String megjegyzes;

    // jog adatok
    private MDMStringReference jogosultminosegKod;
    private MDMStringReference jogKod;

    // teny adatok
    private MDMStringReference tenyKod;

    // JogiJelleg
    private MDMStringReference jogiJellegKod;

    // jogosult
    @Deprecated(forRemoval = true)
    private String szemelyNev;
    @Deprecated(forRemoval = true)
    private String szemelySzulnev;
    @Deprecated(forRemoval = true)
    private String szemelyAnyanev;
    @Deprecated(forRemoval = true)
    private String szemelySzulhely;
    @Deprecated(forRemoval = true)
    private String szemelySzuldat;
    @Deprecated(forRemoval = true)
    private String cegTeljesnev;
    @Deprecated(forRemoval = true)
    private String cegRovidnev;
    @Deprecated(forRemoval = true)
    private String cegAdoszam;
    @Deprecated(forRemoval = true)
    private String cegNyilvantartasiszam;
    private String cim;
    private IngatlanAzonosito terheloIngatlan;

    private String forrasRendszer;
    private String forrasAzonosito;

    private JogTenyKiegeszitoadatok kiegeszitoadatok = new JogTenyKiegeszitoadatok();

    // jogi jelleg kieg adatok
    private IngatlanKiegeszitoadatok ingKiegeszitoadatok = new IngatlanKiegeszitoadatok();

    // hivatkozasok
    private List<BejegyzesHivatkozasDTO> hivatkozasok;

    // hatarozatok
    private HatarozatDTO bejegyzoHatarozat;

    private HatarozatDTO torloHatarozat;

    private Jogosult jogosult;

    private IngatlanAzonosito ingatlanAzonosito;

    @Override
    public int compareTo(BejegyzesDTO o) {
        if (o == null) {
            return 1;
        } else if (this.getBejegyzesSorszam() == null && o.getBejegyzesSorszam() == null) {
            return 0;
        } else if (this.getBejegyzesSorszam() == null) {
            return -1;
        } else if (o.getBejegyzesSorszam() == null) {
            return 1;
        }
        return this.getBejegyzesSorszam().intValue() - o.getBejegyzesSorszam().intValue();
    }
}
