package hu.tigra.eing.ingatlan.inyer.data;

import java.util.HashMap;
import java.util.Map;

/**
 * Ingatlan tulajdoni lapján található elemek típusa.
 */
public enum BejegyzesTipus {

    JOG(5007L),
    TENY(5008L),
    JOGI_JELLEG(0L);

    private long mdmGlobalId;
    private static Map<Long, BejegyzesTipus> BEJEGYZESTIPUS_RESOLVER = new HashMap();

    private BejegyzesTipus(long mdmGlobalId) {
        this.mdmGlobalId = mdmGlobalId;
    }

    public long getMdmGlobalId() {
        return this.mdmGlobalId;
    }

    public static BejegyzesTipus getByMdmGlobalId(long mdmGlobalId) {
        return (BejegyzesTipus) BEJEGYZESTIPUS_RESOLVER.get(mdmGlobalId);
    }

    /**
     * A normál enum .valueOf() megoldáshoz képest egy nullsafe változatot biztosít.
     * Használatára azért van szükség, mert nem teljes BejegyzesTipus értékkészletet kezel ez az enum.
     *
     * @param value a konvertálandó szöveges formátum
     * @return A megfelelő BejegyzesTipus enum vagy amennyiben nem ismert ez a BejegyzesTipus enum-ban akkor null.
     */
    public static BejegyzesTipus resolveFromString(String value) {
        if (value == null) {
            return null;
        }
        try {
            return BejegyzesTipus.valueOf(value.toUpperCase());
        } catch (IllegalArgumentException e) {
            return null;
        }
    }

    /**
     * GlobalId alapján történő enum feloldás
     */
    public static BejegyzesTipus resolveFromGlobalId(Long globalId) {
        if (globalId == null) {
            return null;
        }
        return BEJEGYZESTIPUS_RESOLVER.get(globalId);
    }

}
