package hu.tigra.eing.common.entities.ingatlan;

import hu.tigra.eing.common.entities.mdm.MDMStringReference;

/**
 * Az Ingatlan törvényben (1997. évi CXLI. törvény) meghatározott Ingatlan fekvés értékek.
 */
public enum Fekves {

    BELTERULET(new MDMStringReference(3719L, "Belterület"), "bt"),
    KULTERULET(new MDMStringReference(3720L, "Külterület"), "kt"),
    ZARTKERT(new MDMStringReference(3721L, "Zártkert"), "zk");

    private MDMStringReference mdmReference;

    private String shortName;

    Fekves(MDMStringReference mdmReference, String shortName) {
        this.mdmReference = mdmReference;
        this.shortName = shortName;
    }

    public MDMStringReference getMdmReference() {
        return mdmReference;
    }

    public long getMdmGlobalId() {
        return mdmReference.getGlobalId();
    }

    public String getShortName() {
        return shortName;
    }

    /**
     * MDM GlobalID alapján a Fekves Enum érték feloldása.
     * Amennyiben egyik értéknek sem felel meg, akkor a visszatérési érték null lesz.
     */
    public static Fekves getByMDMGlobalId(long globalId) {
        for (Fekves fekves : Fekves.values()) {
            if (fekves.getMdmReference().getGlobalId().equals(globalId)) {
                return fekves;
            }
        }
        return null;
    }

    /**
     * Fekves enum visszaadása case-insensitive szöveges reprezentáció alapján.
     * Amennyiben egyik értéknek sem felel meg, akkor a visszatérési érték null lesz.
     */
    public static Fekves getByCode(String text) {
        for (Fekves fekves : Fekves.values()) {
            if (fekves.name().equalsIgnoreCase(text) || fekves.getMdmReference().getValue().equalsIgnoreCase(text)) {
                return fekves;
            }
        }
        return null;
    }

}
