package hu.tigra.eing.ingatlan.inyer.data;

import com.fasterxml.jackson.annotation.JsonIgnore;
import hu.tigra.eing.common.core.annotation.AdditionalApiModel;
import hu.tigra.eing.common.core.message.Response;
import hu.tigra.eing.common.entities.ingatlan.IngatlanAzonosito;
import hu.tigra.eing.common.entities.mdm.MDMStringReference;
import hu.tigra.eing.ingatlan.inyer.adatvaltozas.alapadat.BaseIngatlanDTO;
import io.swagger.v3.oas.annotations.media.Schema;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

@Schema(description = "Ingatlan tulajdoni lap szintű adatai")
@AdditionalApiModel
public class IngatlanDTO implements Response {

    private IngatlanAzonosito azonosito;

    /**
     * {@link hu.tigra.eing.common.entities.mdm.MDMStringReference}
     */
    private MDMStringReference ingatlanTipus;

    /**
     * Címek.
     */
    private List<CimDTO> cimek;

    /**
     * Fölreszlet / Építmény / EÖI
     */
    private BaseIngatlanDTO alapadatok;

    /**
     * Fölreszlet / Építmény / EÖI változások
     */
    private List<BaseIngatlanDTO> alapadatValtozasok;

    /**
     * Széljegyek
     */
    private List<SzeljegyResponseDTO> szeljegyek;

    /**
     * Jogok / tények
     */
    private List<BejegyzesDTO> tullapBejegyzesek;

    public List<BejegyzesDTO> getTullap1Bejegyzesek() {
        return getTullapBejegyzesek().stream().filter(t -> t.getTullapresz() == 1L).sorted().collect(Collectors.toList());
    }

    public void setTullap1Bejegyzesek(List<BejegyzesDTO> tullap1Bejegyzesek) {
        getTullapBejegyzesek().removeIf(t -> t.getTullapresz() == 1L);
        getTullapBejegyzesek().addAll(tullap1Bejegyzesek);
    }

    public List<BejegyzesDTO> getTullap2Bejegyzesek() {
        return getTullapBejegyzesek().stream().filter(t -> t.getTullapresz() == 2L).sorted().collect(Collectors.toList());
    }

    public void setTullap2Bejegyzesek(List<BejegyzesDTO> tullap2Bejegyzesek) {
        getTullapBejegyzesek().removeIf(t -> t.getTullapresz() == 2L);
        getTullapBejegyzesek().addAll(tullap2Bejegyzesek);
    }

    public List<BejegyzesDTO> getTullap3Bejegyzesek() {
        return getTullapBejegyzesek().stream().filter(t -> t.getTullapresz() == 3L).sorted().collect(Collectors.toList());
    }

    public void setTullap3Bejegyzesek(List<BejegyzesDTO> tullap3Bejegyzesek) {
        getTullapBejegyzesek().removeIf(t -> t.getTullapresz() == 3L);
        getTullapBejegyzesek().addAll(tullap3Bejegyzesek);
    }

    public List<BejegyzesDTO> getTullapBejegyzesekEgyeb() {
        return getTullapBejegyzesek().stream().filter(t -> t.getTullapresz() > 3L || t.getTullapresz() < 1).sorted().collect(Collectors.toList());
    }

    public void setTullapBejegyzesekEgyeb(List<BejegyzesDTO> tullapEgyebBejegyzesek) {
        getTullapBejegyzesek().removeIf(t -> t.getTullapresz() > 3L || t.getTullapresz() < 1);
        getTullapBejegyzesek().addAll(tullapEgyebBejegyzesek);
    }

    public IngatlanAzonosito getAzonosito() {
        return azonosito;
    }

    public void setAzonosito(IngatlanAzonosito azonosito) {
        this.azonosito = azonosito;
    }

    public BaseIngatlanDTO getAlapadatok() {
        return alapadatok;
    }

    public void setAlapadatok(BaseIngatlanDTO alapadatok) {
        this.alapadatok = alapadatok;
    }

    public List<SzeljegyResponseDTO> getSzeljegyek() {
        return szeljegyek;
    }

    public MDMStringReference getIngatlanTipus() {
        return ingatlanTipus;
    }

    public void setIngatlanTipus(MDMStringReference ingatlanTipus) {
        this.ingatlanTipus = ingatlanTipus;
    }

    public List<CimDTO> getCimek() {
        return cimek;
    }

    public void setCimek(List<CimDTO> cimek) {
        this.cimek = cimek;
    }

    public void setSzeljegyek(List<SzeljegyResponseDTO> szeljegyek) {
        if (szeljegyek != null && !szeljegyek.isEmpty()) {
            this.szeljegyek = szeljegyek.stream().sorted().collect(Collectors.toList());
        } else {
            this.szeljegyek = null;
        }
    }

    public List<BaseIngatlanDTO> getAlapadatValtozasok() {
        return alapadatValtozasok;
    }

    public void setAlapadatValtozasok(List<BaseIngatlanDTO> alapadatValtozasok) {
        this.alapadatValtozasok = alapadatValtozasok;
    }

    @JsonIgnore
    public List<BejegyzesDTO> getTullapBejegyzesek() {
        if (this.tullapBejegyzesek == null) {
            this.tullapBejegyzesek = new ArrayList<>();
        }
        return this.tullapBejegyzesek;
    }

    @JsonIgnore
    public void setTullapBejegyzesek(List<BejegyzesDTO> tullapBejegyzesek) {
        this.tullapBejegyzesek = tullapBejegyzesek;
    }
}
