package hu.tigra.eing.ingatlan.inyer.adatvaltozas.ingatlankieg;

import hu.tigra.eing.common.entities.mdm.MDMStringReference;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.Min;
import jakarta.validation.constraints.NotNull;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.time.Instant;

import static hu.tigra.eing.ingatlan.inyer.adatvaltozas.ingatlankieg.IngatlanKiegeszitoAdatComparator.DEFAULT_JOGTENYKIEGESZITOADAT_COMPARATOR;

/**
 * Általános struktúra a jogtény kiegészítő adatok tárolására.
 * A struktúra minden esetben egy adott Jog vagy Tény értelmezésében értelmezhető csak.
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@Schema(description = "Általános struktúra az ingatlan kiegészítő adatok tárolására.")
public class IngatlanKiegeszitoadat implements Comparable<IngatlanKiegeszitoadat> {

    /**
     * Melyik ING_KIEGESZITOADAT_TIPUS-ra vonatkozik az adat
     */
    @NotNull
    @Min(1)
    @Schema(description = "Melyik ING_KIEGESZITOADATTIPUS-ra vonatkozik az adat", requiredMode = Schema.RequiredMode.REQUIRED)
    private long kiegeszitoadatTipusId;

    /**
     * Mi a ING_KIEGESZITOADAT_TIPUS
     */
    @Schema(description = "Mi a ING_KIEGESZITOADATTIPUS")
    private IngatlanKiegeszitoadatTipus kiegeszitoadatTipus;

    /**
     * A kiegészítő adatok sorrendezésére sorszám alapján
     */
    @Schema(description = "A kiegészítő adatok sorrendezésére sorszám alapján")
    private int sorszam;

    /**
     * A kiegészítő adat konkrét értéke (típustól függően)
     */
    @Schema(description = "Egész szám típusú érték")
    private Long kiegeszitoadatN;
    @Schema(description = "ha a kiegeszitoadatN helyére kód kerül, akkor annak feloldása")
    private MDMStringReference kiegeszitoadatKod;
    @Schema(description = "szöveges típusú érték")
    private String kiegeszitoadatC;
    @Schema(description = "időpont típusú érték")
    private Instant kiegeszitoadatD;
    @Schema(description = "mező felvételének időpontja")
    private Instant datum;

    @Override
    public int compareTo(IngatlanKiegeszitoadat o) {
        return DEFAULT_JOGTENYKIEGESZITOADAT_COMPARATOR.compare(this, o);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getKiegeszitoadatTipusId()).append("[").append(getSorszam()).append("]").append(":");
        if (kiegeszitoadatN != null) {
            sb.append(kiegeszitoadatN);
        } else if (kiegeszitoadatC != null) {
            sb.append(kiegeszitoadatC);
        } else if (kiegeszitoadatD != null) {
            sb.append(kiegeszitoadatD);
        }
        return sb.toString();
    }
}
