package hu.tigra.eing.ingatlan.inyer.adatvaltozas.ingatlankieg;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.Valid;
import lombok.Data;

import java.util.*;
import java.util.stream.Collectors;

@Data
@Schema(description = "az ingatlan kiegészítő adatokat összefogó adatstruktúra")
public class IngatlanKiegeszitoadatok {

    /**
     * Kiegészítő adatok az alap struktúrához
     */
    @Schema(description = "Kiegészítő adatok az alap struktúrához")
    private Map<Long, List<@Valid IngatlanKiegeszitoadat>> adat;

    public IngatlanKiegeszitoadatok() {
        this.adat = new HashMap<>();
    }

    @JsonCreator
    public IngatlanKiegeszitoadatok(@JsonProperty("adat") Map<Long, List<IngatlanKiegeszitoadat>> adat) {
        this();
        if (adat != null) {
            adat.values()
                    .stream()
                    .flatMap(x -> x.stream())
                    .forEach(this::addKiegeszitoadat);
        }
    }

    /**
     * Adott kiegészítő adat típusának megfelelő érték visszaadása (olyan kiegészítő adat típusok esetén ahol a típusból csak egy érték adható meg)
     */
    @JsonIgnore
    public IngatlanKiegeszitoadat getEgyesKiegeszitoadat(Long id) {
        List<IngatlanKiegeszitoadat> kiegeszitoadat = getAdat().get(id);
        if (kiegeszitoadat == null || kiegeszitoadat.isEmpty()) {
            return null;
        }
        return kiegeszitoadat.get(0);
    }

    /**
     * Adott kiegészítő adat típusának megfelelő értékek visszaadása (olyan kiegészítő adat típusok esetén ahol a típusból több érték is megadható)
     */
    @JsonIgnore
    public List<IngatlanKiegeszitoadat> getTobbesKiegeszitoadat(Long id) {
        return getAdat().get(id);
    }

    /**
     * Adott kiegészítő adat típusának megfelelő értékek visszaadása többes típus esetén az adott érték sorszámára hivatkozva
     */
    @JsonIgnore
    public IngatlanKiegeszitoadat getTobbesKiegeszitoadat(Long id, int sorszam) {
        List<IngatlanKiegeszitoadat> kiegeszitoadat = getAdat().get(id);
        if (kiegeszitoadat == null || kiegeszitoadat.isEmpty()) {
            return null;
        }
        return kiegeszitoadat.stream().filter(a -> a.getSorszam() == sorszam).findFirst().orElse(null);
    }

    /**
     * Kiegészítő adat beiilesztése az eddigi struktúrába
     */
    @JsonIgnore
    public void addKiegeszitoadat(IngatlanKiegeszitoadat kiegeszitoadat) {
        List<IngatlanKiegeszitoadat> aktualisErtekek = getTobbesKiegeszitoadat(kiegeszitoadat.getKiegeszitoadatTipusId());
        if (aktualisErtekek == null) {
            aktualisErtekek = new LinkedList<>();
            aktualisErtekek.add(kiegeszitoadat);
            adat.put(kiegeszitoadat.getKiegeszitoadatTipusId(), aktualisErtekek);
            return;
        }
        aktualisErtekek.add(kiegeszitoadat);
        Collections.sort(aktualisErtekek);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("kiegeszitoadatok:{");
        if (adat != null) {
            sb.append(adat.values()
                    .stream()
                    .flatMap(x -> x.stream())
                    .map(IngatlanKiegeszitoadat::toString)
                    .collect(Collectors.joining(","))
            );
        }
        sb.append("}");
        return sb.toString();
    }
}
