package hu.tigra.eing.ingatlan.inyer.adatvaltozas.jogtenykieg;

import hu.tigra.eing.common.entities.mdm.MDMStringReference;
import hu.tigra.eing.ingatlan.inyer.adatvaltozas.jogosult.Jogosult;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.Min;
import jakarta.validation.constraints.NotNull;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;
import java.time.Instant;

import static hu.tigra.eing.ingatlan.inyer.adatvaltozas.jogtenykieg.JogTenyKiegeszitoAdatComparator.DEFAULT_JOGTENYKIEGESZITOADAT_COMPARATOR;

/**
 * Általános struktúra a jogtény kiegészítő adatok tárolására.
 * A struktúra minden esetben egy adott Jog vagy Tény értelmezésében értelmezhető csak.
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@Schema(description = "Általános struktúra a jogtény kiegészítő adatok tárolására.")
public class JogTenyKiegeszitoadat implements Comparable<JogTenyKiegeszitoadat> {

 /**
  * Melyik JT_KIEGESZITOADAT_TIPUS-ra vonatkozik az adat
  */
 @NotNull
 @Min(1)
 @Schema(description = "Melyik JT_KIEGESZITOADAT_TIPUS-ra vonatkozik az adat", requiredMode = Schema.RequiredMode.REQUIRED)
 private long kiegeszitoadatTipusId;

 /**
  * Mi a JT_KIEGESZITOADAT_TIPUS
  */
 @Schema(description = "Mi a JT_KIEGESZITOADAT_TIPUS")
 private JogTenyKiegeszitoadatTipus kiegeszitoadatTipus;

 /**
  * A kiegészítő adatok sorrendezésére sorszám alapján
  */
 @Schema(description = "A kiegészítő adatok sorrendezésére sorszám alapján")
 private int sorszam;

 /**
  * A kiegészítő adat konkrét értéke (típustól függően)
  */
 @Schema(description = "Egész szám típusú érték")
 private Long kiegeszitoadatN;
 @Schema(description = "ha a kiegeszitoadatN helyére kód kerül, akkor annak feloldása")
 private MDMStringReference kiegeszitoadatKod;
 @Schema(description = "Tizedes szám típusú érték")
 private BigDecimal kiegeszitoadatFL;
 @Schema(description = "szöveges típusú érték")
 private String kiegeszitoadatC;
 @Schema(description = "időpont típusú érték")
 private Instant kiegeszitoadatD;
 @Schema(description = "jogosult típusú érték")
 private Jogosult kiegeszitoadatJ;
 @Schema(description = "ha a kiegeszitoadatN helyére címreg település kerül, akkor annak feloldása")
 private MDMStringReference kiegeszitoadatCimregTelepules;
 @Schema(description = "mező felvételének időpontja")
 private Instant datum;

 @Override
 public int compareTo(JogTenyKiegeszitoadat o) {
  return DEFAULT_JOGTENYKIEGESZITOADAT_COMPARATOR.compare(this, o);
 }

 @Override
 public String toString() {
  StringBuilder sb = new StringBuilder();
  sb.append(getKiegeszitoadatTipusId()).append("[").append(getSorszam()).append("]").append(":");
  if (kiegeszitoadatN != null) {
   sb.append(kiegeszitoadatN);
  } else if (kiegeszitoadatC != null) {
   sb.append(kiegeszitoadatC);
  } else if (kiegeszitoadatD != null) {
   sb.append(kiegeszitoadatD);
  }
  return sb.toString();
 }
}
